@@ -1,6 +1,10 @@
 __func_alias__ = {"ctx_": "ctx"}
 
 
+def __init__(hub):
+    hub.exec.test.ACCT = ["test"]
+
+
 def ping(hub):
     return {"result": True, "ret": True}
 
