@@ -1,3 +1,4 @@
+import pop.hub
 from typing import Any
 from typing import Dict
 from typing import Iterable
@@ -23,10 +24,15 @@ async def run(
         path = f"exec.{path}"
 
     func = getattr(hub, path)
-    params = func.signature.parameters
+    if isinstance(func, pop.hub.ReverseSub):
+        params = func._resolve().signature.parameters
+    else:
+        params = func.signature.parameters
 
     if "ctx" in params:
-        ctx = await hub.idem.ex.ctx(path, acct_file, acct_key, acct_profile)
+        ctx = await hub.idem.ex.ctx(
+            path, acct_file=acct_file, acct_key=acct_key, acct_profile=acct_profile
+        )
         args.insert(0, ctx)
 
     ret = func(*args, **kwargs)
@@ -36,22 +42,28 @@ async def run(
 async def ctx_(
     hub,
     path: str,
+    acct_profile: str = "default",
     acct_file: str = None,
     acct_key: str = None,
-    acct_profile: str = "default",
 ):
     """
     :param hub:
     :param path:
+    :param acct_profile:
     :param acct_file:
     :param acct_key:
-    :param acct_profile:
     :return:
     """
     ctx = data.NamespaceDict()
 
-    first = path[path.index(".") + 1 :]
-    sname = first[: first.index(".")]
+    parts = path.split(".")
+    try:
+        parts.remove("exec")
+    except ValueError:
+        ...
+
+    sname = parts[0]
+
     acct_paths = (f"exec.{sname}.ACCT", f"states.{sname}.ACCT")
 
     if acct_file and acct_key:
