@@ -1,7 +1,3 @@
-# Import python libs
-import asyncio
-
-# import local libs
 import pop.loader
 
 
@@ -25,7 +21,14 @@ STATE_REQUISITE_KEYWORDS = frozenset(
     ]
 )
 STATE_REQUISITE_IN_KEYWORDS = frozenset(
-    ["onchanges_in", "onfail_in", "prereq_in", "watch_in", "require_in", "listen_in",]
+    [
+        "onchanges_in",
+        "onfail_in",
+        "prereq_in",
+        "watch_in",
+        "require_in",
+        "listen_in",
+    ]
 )
 STATE_RUNTIME_KEYWORDS = frozenset(
     [
@@ -145,16 +148,13 @@ async def run(hub, name, ctx, low, seq_comp, running, run_num):
         for rdat in rlist:
             if "pre" in rdat:
                 ret = rdat["pre"](*call["args"], **call["kwargs"])
-                if asyncio.iscoroutine(ret):
-                    ret = await ret
+                await hub.pop.loop.unwrap(ret)
     ret = func(*call["args"], **call["kwargs"])
-    if asyncio.iscoroutine(ret):
-        ret = await ret
+    ret = await hub.pop.loop.unwrap(ret)
     for req, rlist in rdats.items():
         for rdat in rlist:
             if "post" in rdat:
                 ret = rdat["post"](*call["args"], **call["kwargs"])
-                if asyncio.iscoroutine(ret):
-                    ret = await ret
+                ret = await hub.pop.loop.unwrap(ret)
     ret["__run_num"] = run_num
     running[tag] = ret
