@@ -7,7 +7,7 @@ async def start(hub, name):
     is present an exception will be raised
     """
     if not hub.idem.RUNS[name].get("low"):
-        raise ValueError()
+        raise ValueError(f"No low data for '{name}' in RUNS")
     ctx = data.NamespaceDict({"run_name": name, "test": hub.idem.RUNS[name]["test"]})
     rtime = hub.idem.RUNS[name]["runtime"]
     low = hub.idem.RUNS[name].get("low")
@@ -19,7 +19,7 @@ async def start(hub, name):
         # TODO: make the errors float up
         seq = hub.idem.req.seq.init.seq(low, hub.idem.RUNS[name]["running"])
         if seq == old_seq:
-            raise Exception()
+            raise Exception(f"No sequence changed for '{name}'")
         await getattr(hub, ref)(name, ctx, seq, low, hub.idem.RUNS[name]["running"])
         await hub.idem.resolve.render(name)
         await hub.idem.state.compile(name)
@@ -32,8 +32,7 @@ async def start(hub, name):
             else:
                 break
         if len(seq) == old_seq_len:
-            # We made no progress! Recursive requisite!
-            raise Exception()
+            raise RecursionError(f"No progress made on '{name}', Recursive Requisite!")
         old_seq = seq
         old_seq_len = len(seq)
         # Check for any new, available blocks to render
