@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Test States
 ===========
@@ -30,11 +29,14 @@ calls, e.g. running, calling, logging, output filtering etc.
       test.fail_with_changes:
         - name: foo
 """
-# Import Python libs
 import random
 
 TREQ = {
-    "treq": {"require": ["test.nop",]},
+    "treq": {
+        "require": [
+            "test.nop",
+        ]
+    },
 }
 
 
